meshmode: High-Order Meshes and Discontinuous Function Spaces
=============================================================

.. image:: https://gitlab.tiker.net/inducer/meshmode/badges/main/pipeline.svg
    :alt: Gitlab Build Status
    :target: https://gitlab.tiker.net/inducer/meshmode/commits/main
.. image:: https://github.com/inducer/meshmode/workflows/CI/badge.svg
    :alt: Github Build Status
    :target: https://github.com/inducer/meshmode/actions?query=branch%3Amain+workflow%3ACI
.. image:: https://badge.fury.io/py/meshmode.png
    :alt: Python Package Index Release Page
    :target: https://pypi.org/project/meshmode/

* `Source code on Github <https://github.com/inducer/meshmode>`_
* `Documentation <https://documen.tician.de/meshmode>`_

.. TODO
